@@ -5,8 +5,10 @@
 #' \code{\link{input_indicator_create}}
 #' @param inverse A Leontieff-inverse created by \code{\link{leontieff_inverse_create}}.
 #' @param digits Rounding digits, defaults to \code{NULL}, in which case 
-#' no rounding takes place.  
-#' @importFrom dplyr select one_of mutate_at
+#' no rounding takes place. Rounding is important if you replicate examples from the literature,
+#' rounding differences can add up to visible differences in matrix equations.
+#' @importFrom dplyr select mutate_at
+#' @importFrom rlang .data
 #' @return A data frame with the vector of multipliers and the an 
 #' auxiliary metadata column (for joining with other matrixes.)
 #' @family multiplier functions
@@ -26,17 +28,17 @@
 #' @export
 
 input_multipliers_create <- function ( input_requirements,
-                                    inverse,
-                                    digits = NULL) { 
-  . <- NULL
+                                       inverse,
+                                       digits = NULL) { 
+
+  names_direct <- names (input_requirements)
   
-  names_direct <- names ( input_requirements )
   new_key_column <- input_requirements %>%
     dplyr::select (1:2) %>%
-    dplyr::mutate_at ( vars(1), funs(gsub(pattern ="_indicator",
+    mutate_at ( vars(1), ~gsub(pattern ="_indicator",
                                           replacement = "", 
-                                          x =. )) ) %>%
-    dplyr::mutate_at ( vars(1), funs(paste0(., "_multiplier")))
+                                          x =.data ) ) %>%
+    mutate_at ( vars(1), ~paste0(.data, "_multiplier"))
   
   
   col_n <- ncol(input_requirements)
@@ -55,11 +57,14 @@ input_multipliers_create <- function ( input_requirements,
   effects <- input_requirements_matrix %*% inverse 
   multipliers <- effects
   
-  for ( i in 1:nrow(effects)) {
+  for ( i in seq_len(nrow(effects))) {
     multipliers[i, ] <- effects[i, ] /  input_requirements_matrix[i,]
   }
   
-  if ( !is.null(digits)) {
+  ## Rounding is important when you compare with peer-reviewed literature sources. 
+  ## You want the same rounding to be able to replicate the results.
+  
+  if ( !is.null(digits) ) {
     if ( digits>=0 ) 
       multipliers <- round ( multipliers, digits )
    }
