@@ -13,8 +13,9 @@ compensation_indicator <- input_indicator_create(netherlands_2006, 'compensation
 
 I_nl <- leontieff_inverse_create( input_coeff_nl )
 
-mult <- input_multipliers_create(input_requirements = compensation_indicator, 
-                             inverse = I_nl)
+mult <- input_multipliers_create(
+                      input_requirements = compensation_indicator, 
+                      inverse = I_nl)
 
 published_multipliers <- c(2.466, 2.333, 1.84, 2.372, 1.953, 1.417 )
 
